# BA CCS Track, Institut für Publizistik, JGU Mainz
# 2024-04-15

## Instagram 

library(tidyverse)
theme_set(theme_minimal())

# Instagram views ---------------------------------------------------------

insta_views <- jsonlite::fromJSON("posts_viewed.json")$impressions_history_posts_seen %>%
  jsonlite::flatten() %>%
  as_tibble()

insta_views

# Zeitvariablen erstellen
insta_views <- insta_views %>%
  rename(
    account = string_map_data.Author.value,
    timestamp = string_map_data.Time.timestamp
  ) %>%
  mutate(
    timestamp = as.POSIXct(timestamp, origin = "1970-01-01"),
    day = as.Date(timestamp),
    hour = lubridate::hour(timestamp),
    weekday = lubridate::wday(timestamp, label = TRUE, week_start = 1)
  )

insta_views

# Verlauf
insta_views %>%
  count(day) %>%
  ggplot(aes(x = day, y = n)) +
  geom_col() +
  labs(title = "Instagram posts viewed per day")

# Uhrzeit
insta_views %>%
  count(hour) %>%
  ggplot(aes(x = hour, y = n)) +
  geom_col() +
  labs(title = "Instagram posts viewed per hour of day")

# Wochentage
insta_views %>%
  count(weekday) %>%
  ggplot(aes(x = weekday, y = n)) +
  geom_col() +
  labs(title = "Instagram posts viewed per day of the week")

# Instagram Followings ----------------------------------------------------

insta_follow <- jsonlite::fromJSON("following.json")$relationships_following %>%
  unnest(string_list_data) %>%
  select(user = value, timestamp) %>%
  mutate(
    timestamp = as.POSIXct(timestamp, origin = "1970-01-01"),
    day = as.Date(timestamp),
    hour = lubridate::hour(timestamp),
    weekday = lubridate::wday(timestamp, label = TRUE, week_start = 1)
  )

# Followings aggregieren
insta_follow_counts <- insta_follow %>%
  count(day) %>%
  mutate(cumulative_n = cumsum(n))

insta_follow_counts

# Zeitverlauf
insta_follow_counts %>%
  ggplot(aes(x = day, y = cumulative_n)) +
  geom_line(group = 1) +
  labs(title = "Instagram followings over time")

## TikTok

library(tidyverse)
theme_set(theme_minimal())

# Diese Datei vorher hochladen!
tiktok <- jsonlite::fromJSON("data/user_data.json")

# TikTok Logins -----------------------------------------------------------

tt_logins <- tiktok$Activity$`Login History`$LoginHistoryList %>%
  as_tibble()

tt_logins

# Zeitvariablen erstellen
tt_logins <- tt_logins %>%
  mutate(
    day = as.Date(Date),
    hour = lubridate::hour(Date),
    weekday = lubridate::wday(Date, label = TRUE, week_start = 1)
  )

tt_logins

# Verlauf
tt_logins %>%
  count(day) %>%
  ggplot(aes(x = day, y = n)) +
  geom_col() +
  labs(title = "TikTok logins per day")

# Uhrzeit
tt_logins %>%
  count(hour) %>%
  ggplot(aes(x = hour, y = n)) +
  geom_col() +
  labs(title = "TikTok logins per hour of day")

# Wochentage
tt_logins %>%
  count(weekday) %>%
  ggplot(aes(x = weekday, y = n)) +
  geom_col() +
  labs(title = "TikTok logins per day of the week")

# Viewing History ---------------------------------------------------------

tt_views <- tiktok$Activity$`Video Browsing History`$VideoList %>%
  as_tibble() %>%
  mutate(
    day = as.Date(Date),
    hour = lubridate::hour(Date),
    weekday = lubridate::wday(Date, label = TRUE, week_start = 1)
  )

tt_views

# Verlauf
views_per_day <- tt_views %>%
  count(day)

views_per_day

# Statistiken
views_per_day %>%
  summary()

views_per_day %>%
  ggplot(aes(x = day, y = n)) +
  geom_col() +
  labs(title = "TikTok videos watched per day")

# Direct Messages ---------------------------------------------------------

tt_dm <- tiktok$`Direct Messages`$`Chat History`$ChatHistory %>%
  bind_rows() %>%
  as_tibble()

tt_dm

# Chat partner
tt_dm %>%
  count(From, sort = TRUE)

