# BA CCS Track, Institut für Publizistik, JGU Mainz
# 2024-04-15

library(tidyverse)
theme_set(theme_minimal())

## Tabellarische Daten

### CSV-Dateien

# Source:
taylor_swift_lyrics <- readr::read_csv("https://raw.githubusercontent.com/rfordatascience/tidytuesday/master/data/2020/2020-09-29/taylor_swift_lyrics.csv")
taylor_swift_lyrics

### Andere Formate

library(arrow)
# Source: https://huggingface.co/datasets/bjoernp/tagesschau-2018-2023
tagesschau_archiv <- arrow::read_parquet("https://huggingface.co/api/datasets/bjoernp/tagesschau-2018-2023/parquet/default/train/0.parquet")
tagesschau_archiv

### Schlagzeilen im Zeitverlauf

tagesschau_archiv |>
  mutate(
    ukraine = str_detect(short_text, "Ukrain|ukrain"),
    week = floor_date(as.Date(date), "week")
  ) |>
  group_by(week) |>
  summarise(n_ukraine = sum(ukraine)) |>
  ggplot(aes(x = week, y = n_ukraine)) +
  geom_line() +
  scale_x_date(
    date_breaks = "1 year",
    date_labels = "%Y"
  ) +
  labs(
    x = "", y = "Ukraine-bezogene Beiträge pro Woche",
    title = "Ukraine-Berichterstattung in der Tagesschau"
  )

### Aufgabe

## Spezifische R-Pakete

### Mastodon-Posts

library(rtoot)
ard_toots <- rtoot::get_timeline_public(instance = "ard.social")
ard_toots

### TikTok-Videos

remotes::install_github("JBGruber/traktok", dependencies = F)
library(traktok)
traktok::tt_get_cookies(x = "data/tt_cookie.txt")

ed <- traktok::tt_user_videos("https://www.tiktok.com/@edsheeran")
ed

ed_video1 <- traktok::tt_videos("https://www.tiktok.com/@edsheeran/video/7289455403551804704")
ed_video1 |>
  glimpse()

### TikTok-Coverbilder sammeln

library(magick)
library(gifski)
traktok::tt_json("https://www.tiktok.com/@edsheeran")$ItemModule |>
  map("video") |>
  map_chr("cover") |>
  magick::image_read() |>
  magick::image_resize("320x") |>
  magick::image_write_gif("tiktok_ed.gif", delay = 1)
magick::image_read("tiktok_ed.gif")

### Aufgabe

## Feeds und Web-APIs

### RSS Feeds

library(tidyRSS)
spiegel <- tidyRSS::tidyfeed("https://www.spiegel.de/schlagzeilen/tops/index.rss")
spiegel |>
  glimpse()

### JSON-APIs

library(jsonlite)
# Source: https://github.com/AndreasFischer1985/tagesschau-api
tagesschau_news <- jsonlite::fromJSON("https://www.tagesschau.de/api2/news")$news |>
  as_tibble()
tagesschau_news

### Bildergallerie aus Sportmeldungen

sport_news <- jsonlite::fromJSON("https://www.tagesschau.de/api2/news?ressort=sport")$news |>
  as_tibble()

sport_news$teaserImage$imageVariants$`1x1-144` |>
  na.omit() |>
  head(15) |>
  magick::image_read() |>
  magick::image_montage(tile = 5, geometry = "x120+2+2")

### Aufgabe

## Web-Scraping

### HTML-Tabellen

library(rvest)
afi_list <- rvest::read_html("https://en.wikipedia.org/wiki/AFI%27s_100_Years...100_Movies_(10th_Anniversary_Edition)") |>
  rvest::html_table()

afi_list

afi_list[2]

### HTML Scraping

heute_headlines <- rvest::read_html("https://www.heute.de") |>
  rvest::html_elements("h3.teaser-title")
length(heute_headlines)

heute_headlines |>
  rvest::html_text() |>
  str_squish() |>
  head()

heute_headlines |>
  rvest::html_elements("a") |>
  rvest::html_attr("href") |>
  head()

### Anteil Paywall-Artikel in Le Monde 

lemonde <- rvest::read_html("https://www.lemonde.fr/")

articles <- lemonde |>
  rvest::html_elements("div.article")

paywalled <- lemonde |>
  rvest::html_elements("div.article span.sr-only")

paywall_share <- length(paywalled) / length(articles)
paywall_share

### Aufgabe

