# BA CCS Track, Institut für Publizistik, JGU Mainz
# 2024-04-15

library(tidyverse)
theme_set(theme_minimal())

# remotes::install_github("ccsmainz/hfapi", dependencies = FALSE, force = TRUE)
library(hfapi)
library(quanteda)

# Datensatz laden
load(url("http://varianceexplained.org/files/trump_tweets_df.rda"))
tweets <- trump_tweets_df |>
  select(id, statusSource, text, created) |>
  # Die verschiedenen Betriebssysteme extrahieren
  extract(statusSource, "source", "Twitter for (.*?)<") |>
  filter(source %in% c("iPhone", "Android")) |>
  mutate(text = stringi::stri_enc_toutf8(text, validate = T))
tweets

## Worthäufigkeiten und reguläre Ausdrücke

tweets |>
  mutate(hillary = str_count(text, "Hillary")) |>
  select(text, hillary) |>
  tail()

tweets |>
  mutate(hashtag = str_extract(text, "#\\w+")) |>
  select(text, hashtag) |>
  count(hashtag, sort = TRUE) |>
  na.omit()

### Reguläre Ausdrücke erstellen

### Hashtag-Verwendung in Tweets

tweets |>
  mutate(hashtags = str_count(text, "#\\w+")) |>
  t.test(hashtags ~ source, data = _)

### Aufgabe

## Named Entity Recognition

tweet_entities <- hfapi::text_ner(tweets$text[1:100])
tweet_entities |>
  as_tibble()

tweet_entities |>
  filter(entity_group == "LOC") |>
  count(word, sort = TRUE) |>
  as_tibble()

### Aufgabe

## Numerische Repräsentation von Text

## Document-Feature-Matrix

tweets$text |>
  quanteda::tokens() |>
  quanteda::dfm()

tweets$text |>
  quanteda::tokens() |>
  quanteda::dfm() |>
  quanteda::topfeatures()

### Aufgabe

### Zwischenschritte zur Document-Feature-Matrix

### Contextual Word Embeddings

## Diktionärcodierung

dict <- quanteda::dictionary(list(negative = c("sad"), positive = c("great", "fantastic")))

dict_coding <- tweets$text |>
  quanteda::tokens() |>
  quanteda::dfm() |>
  quanteda::dfm_lookup(dictionary = dict) |>
  as_tibble()

dict_coding

dict_coding |>
  summarise(
    m_negative = mean(negative),
    m_positive = mean(positive)
  )

tweets$text |>
  quanteda::tokens() |>
  quanteda::dfm() |>
  quanteda::dfm_lookup(dictionary = data_dictionary_LSD2015) |>
  as_tibble() |>
  cbind(tweets) |>
  group_by(source, created = floor_date(created, unit = "month")) |>
  summarise(sentiment = mean(positive - negative, na.rm = T)) |>
  ggplot(aes(x = created, y = sentiment, color = source)) +
  geom_line()

### Aufgabe

## Textklassifikation mit Deep Learning

tweets |>
  filter(id %in% c("760246732152311808", "760783130978648064", "761892829434183684")) |>
  pull(text) |> # Textspalte nach dem Filtern auswählen
  hfapi::text_classification(url = "https://api-inference.huggingface.co/models/distilbert-base-uncased-finetuned-sst-2-english")

## Sentiment-Score mit Deep Learning

tweets_small <- tweets |>
  # Stratifiziertes Sample
  group_by(source) |>
  slice_head(n = 50)

tweets_small |>
  pull(text) |>
  hfapi::text_classification(url = "https://api-inference.huggingface.co/models/distilbert-base-uncased-finetuned-sst-2-english") |>
  # Binäre Variable erstellen mit if_else
  mutate(negative = if_else(NEGATIVE > 0.5, 1, 0)) |>
  # Hinzufügen der Variablen aus dem Datensatz mit left_join()
  left_join(tweets_small, by = "text") |>
  count(source, negative)

### Aufgabe

