# BA CCS Track, Institut für Publizistik, JGU Mainz
# 2024-04-15

# remotes::install_github("ccsmainz/hfapi", dependencies = FALSE, force = TRUE)
library(tidyverse)
theme_set(theme_minimal())
library(hfapi)
library(magick)

## Zero-shot Bildklassifikation

magick::image_read("https://images.pexels.com/photos/2975498/pexels-photo-2975498.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=2")

hfapi::image_zeroshot("https://images.pexels.com/photos/2975498/pexels-photo-2975498.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=2", labels = c("demonstration", "sporting event"))

### Aufgabe

## Zero-shot Textklassifikation

### Generative LLM (z.B. ChatGPT)

### Natural Language Inference (NLI)

load(url("http://varianceexplained.org/files/trump_tweets_df.rda"))
tweets <- trump_tweets_df |>
  select(id, statusSource, text, created) |>
  # Die verschiedenen Betriebssysteme extrahieren
  extract(statusSource, "source", "Twitter for (.*?)<") |>
  filter(source %in% c("iPhone", "Android")) |>
  mutate(text = stringi::stri_enc_toutf8(text, validate = T))
tweets

tweets |>
  filter(id %in% c("760246732152311808", "760783130978648064", "761892829434183684")) |>
  pull(text) |> # Textspalte nach dem Filtern auswählen
  hfapi::text_zeroshot(url = "https://api-inference.huggingface.co/models/facebook/bart-large-mnli", labels = c("about immigration", "about foreign politics"))

tweets_topics <- tweets |>
  slice_head(n = 50) |> # Erste 50 Tweets
  pull(text) |> # Textspalte nach dem Filtern auswählen
  hfapi::text_zeroshot(
    url = "https://api-inference.huggingface.co/models/facebook/bart-large-mnli",
    labels = c("about immigration", "about foreign politics")
  ) |>
  mutate(prediction = if_else(scores >= .8, 1, 0))

tweets_topics |>
  group_by(labels) |>
  count(prediction) |>
  mutate(prediction = as.character(prediction)) %>% # Nur für die grafische Darstellung
  ggplot(aes(x = labels, y = n, fill = prediction)) +
  geom_col(position = "dodge") +
  labs(x = "", y = "n")

### Aufgabe

## Sentiment-Score mit NLI

tweets_small <- tweets |>
  # Stratifiziertes Sample
  group_by(source) |>
  slice_head(n = 50)

tweets_small |>
  pull(text) |>
  hfapi::text_zeroshot(url = "https://api-inference.huggingface.co/models/facebook/bart-large-mnli", labels = c("negative", "positive")) |>
  filter(labels == "negative") |>
  # Binäre Variable erstellen mit if_else
  mutate(negative = if_else(scores > 0.8, 1, 0)) |>
  # Hinzufügen der Variablen aus dem Datensatz mit left_join()
  left_join(tweets_small, by = c("sequence" = "text")) |>
  count(source, negative)

